==> ics_ipa_interface-1.0.0.tar.gz: ics_ipa_interface-1.0.0/ics_ipa_interface/ics_ipa_interface.py <==
import json
from importlib import import_module
from docopt import docopt


def ipa_init(script_name: str = 'script.py', version: str = '1.0', message: str = '') -> None:
    '''
    * The ipa_init function allows you to set the the name and version information of
    * your script. This is allows command line help to display the information accurately.

    * Note ipa_init function must be called before any other ipa function for the change to
    * take affect
    '''
    __read_args(script_name, version, message) 


def get_data_files() -> [str]:
    '''
    * The get_data_files function returns the data files used.

    * Note: If you are in desktop mode this function will display a the
    * file dialog the first time it's called. After being called
    * a cached version of the results will be returned from then on.
    '''
    if hasattr(get_data_files, 'data_files'):
        return get_data_files.data_files
    desktop_options = {}
    # options['initialdir'] = '{0}'.format(os.path.expanduser('~'))
    desktop_options['filetypes'] = [
        ("Data files", "*.dat *.log *.mdf *.mf4 *.db"), ('all files', '.*')]
    desktop_options['title'] = 'Select list of input data files and click open.'
    desktop_options['defaultextension'] = '.db'
    get_data_files.data_files = __to_array_of_paths(__get_files('data_files', desktop_options))
    return get_data_files.data_files


def get_config_files() -> [str]:
    '''
    * The get_config_files function returns the config files used.

    * Note: If you are in desktop mode this function will display a the
    * file dialog the first time it's called. After being called
    * a cached version of the results will be returned from then on.
    '''
    if hasattr(get_config_files, "config_files"):
        return get_config_files.config_files
    desktop_options = {}
    desktop_options['filetypes'] = [("Lookup files", "*.sl *.asl"), ("Signal Lookup files", "*.sl"),
                                    ("Aliased Signal Lookup files", "*.asl"), ("All files", "*.*")]
    desktop_options['title'] = "Select script config file (*.als) and click open."
    get_config_files.config_files = __to_array_of_paths(__get_files('config_files', desktop_options))
    return get_config_files.config_files


def get_output_dir() -> str:
    '''
    * The get_output_dir function returns the output directory that must be used.

    * Note: If you are in desktop mode this function will display a the
    * directory dialog the first time it's called. After being called
    * a cached version of the results will be returned from then on.
    '''
    if hasattr(get_output_dir, "output_dir"):
        return get_output_dir.output_dir
    desktop_options = {}
    get_output_dir.output_dir = __get_dir('output_dir', desktop_options)
    return get_output_dir.output_dir


def update_progress(name: str = 'Master', percent: float = None, message: str = None) -> None:
    # pylint: disable=unused-argument
    '''
    * Allows the user to identify the prograss of the script

    * name: Is the of the progress bar master being the full script progress
    * percent: is a optional way to update progress.
    * message: is a optional way to update progress.
    '''
    # TODO
    return


def using_ipa_file() -> bool:
    '''
    received ipa file as argument
    '''
    return __is_using_ipa_file()


def get_data_attribute_from_ipa_file(data_file_path: str, attribute: str):
    '''
    get attributes passed alongside the file path
    if attribute is not passed None is returned
    '''
    ipa_file = __get_ipa_file()
    if ipa_file is None:
        return None
    path = filter(lambda file: file['path'] ==
                  data_file_path, ipa_file['data_files'])
    if attribute in path:
        return path[attribute]
    else:
        return None


def __read_args(script_name='script.py', version='1.0', message=''):
    if not hasattr(__read_args, "args"):
        args = '''
        {message}
Usage:
  {scriptPy}
  {scriptPy} <IPA_FILE>
  {scriptPy} [--data_files=<FILE>]... [--config_files=<FILE>]... --output_dir=<FILE>
  {scriptPy} (-h | --help)
  {scriptPy} --version

Options:
  -h --help     Show this screen.
  --version     Show version.
  -d FILE --data_files=<FILE>   The data files that are used.
  -c FILE --config_files=<FILE> The config files that are used.
  -o FILE --output_dir=<FILE>   The output directory. This is required if the script output directory.
'''
        __read_args.args = docopt(args.format(
            scriptPy=script_name, message=message), version=version)
    return __read_args.args


def __listafy(argument):
    '''make argument a list if it is not'''
    if not isinstance(argument, list):
        argument = [argument]
    return argument


def __is_strings(argument):
    return isinstance(argument, str)


def __is_list_of_strings(argument):
    if not isinstance(argument, list):
        return False
    return all(isinstance(item, str) for item in argument)


def __is_using_ipa_file():
    return __read_args()['<IPA_FILE>'] is not None


def __get_args():
    ipa_file = __get_ipa_file()
    if ipa_file is not None:
        return ipa_file
    else:
        return __read_args()


def __get_files(file_arg, desktop_options):
    args = __get_args()
    if not __is_using_ipa_file():
        file_arg = '--' + file_arg
    if file_arg in args:
        files = __listafy(args[file_arg])
        return files
    elif __is_using_ipa_file():
        raise TypeError(
            "the {files} argument is not included in IPA_FILE".format(files=file_arg))
    else:
        mtk = None
        mtk_filedialog = None
        try:
            mtk = import_module('tkinter')
            mtk_filedialog = import_module('tkinter.filedialog')
        except ModuleNotFoundError as err:
            raise err

        root = mtk.Tk()
        root.withdraw()
        root.focus_force()
        root.wm_attributes('-topmost', 1)
        return list(mtk_filedialog.askopenfilenames(**desktop_options))


def __get_dir(dir_arg, desktop_options):
    args = __get_args()
    if not __is_using_ipa_file():
        dir_arg = '--' + dir_arg
    if dir_arg in args:
        if __is_strings(args[dir_arg]):
            return args[dir_arg]
        else:
            raise TypeError(
                "the {dir_arg} argument is invalid".format(dir_arg=dir_arg))
    elif __is_using_ipa_file():
        raise TypeError(
            "the {dir_arg} argument is not included in IPA_FILE".format(dir_arg=dir_arg))
    else:
        mtk = None
        mtk_filedialog = None
        try:
            mtk = import_module('tkinter')
            mtk_filedialog = import_module('tkinter.filedialog')
        except ModuleNotFoundError as err:
            raise err

        root = mtk.Tk()
        root.withdraw()
        root.focus_force()
        root.wm_attributes('-topmost', 1)
        return list(mtk_filedialog.askdirectory(**desktop_options))


def __to_array_of_paths(path_object):
    if (type(path_object) is list):
        paths = []
        for file in path_object:
            if type(file) is dict and 'path' in file and type(file['path']) is str:
                paths.append(file['path'])
            elif type(file) is str:
                paths.append(file)
        return paths
    elif (type(path_object) is str):
        return [path_object]
    else:
        return []


def __get_ipa_file():
    if hasattr(__get_ipa_file, 'ipa_file'):
        return __get_ipa_file.ipa_file
    if __is_using_ipa_file():
        __get_ipa_file.ipa_file = json.load(open(__read_args()['<IPA_FILE>']))
        return __get_ipa_file.ipa_file
    return None

==> ics_ipa_interface-1.0.1.tar.gz: ics_ipa_interface-1.0.1/ics_ipa_interface/ics_ipa_interface.py <==
import json
from importlib import import_module
from docopt import docopt


def ipa_init(script_name: str = 'script.py', version: str = '1.0', message: str = '') -> None:
    '''
    * The ipa_init function allows you to set the the name and version information of
    * your script. This is allows command line help to display the information accurately.

    * Note ipa_init function must be called before any other ipa function for the change to
    * take affect
    '''
    __read_args(script_name, version, message)


def get_data_files() -> [str]:
    '''
    * The get_data_files function returns the data files used.

    * Note: If you are in desktop mode this function will display a the
    * file dialog the first time it's called. After being called
    * a cached version of the results will be returned from then on.
    '''
    if hasattr(get_data_files, 'data_files'):
        return get_data_files.data_files
    desktop_options = {}
    # options['initialdir'] = '{0}'.format(os.path.expanduser('~'))
    desktop_options['filetypes'] = [
        ("Data files", "*.dat *.log *.mdf *.mf4 *.db"), ('all files', '.*')]
    desktop_options['title'] = 'Select list of input data files and click open.'
    desktop_options['defaultextension'] = '.db'
    get_data_files.data_files = __raise_if_none(__to_array_of_paths(
        __get_files('data_files', desktop_options)))
    return get_data_files.data_files


def get_config_files() -> [str]:
    '''
    * The get_config_files function returns the config files used.

    * Note: If you are in desktop mode this function will display a the
    * file dialog the first time it's called. After being called
    * a cached version of the results will be returned from then on.
    '''
    if hasattr(get_config_files, "config_files"):
        return get_config_files.config_files
    desktop_options = {}
    desktop_options['filetypes'] = [("Lookup files", "*.sl *.asl"), ("Signal Lookup files", "*.sl"),
                                    ("Aliased Signal Lookup files", "*.asl"), ("All files", "*.*")]
    desktop_options['title'] = "Select script config file (*.als) and click open."
    get_config_files.config_files = __raise_if_none(__to_array_of_paths(
        __get_files('config_files', desktop_options)))
    return get_config_files.config_files


def get_output_dir() -> str:
    '''
    * The get_output_dir function returns the output directory that must be used.

    * Note: If you are in desktop mode this function will display a the
    * directory dialog the first time it's called. After being called
    * a cached version of the results will be returned from then on.
    '''
    if hasattr(get_output_dir, "output_dir"):
        return get_output_dir.output_dir
    desktop_options = {}
    get_output_dir.output_dir = __raise_if_none(__get_directory('output_dir', desktop_options))
    return get_output_dir.output_dir


def update_progress(name: str = 'Master', percent: float = None, message: str = None) -> None:
    # pylint: disable=unused-argument
    '''
    * Allows the user to identify the prograss of the script

    * name: Is the of the progress bar master being the full script progress
    * percent: is a optional way to update progress.
    * message: is a optional way to update progress.
    '''
    # TODO
    return


def using_ipa_file() -> bool:
    '''
    received ipa file as argument
    '''
    return __is_using_ipa_file()


def get_data_attribute_from_ipa_file(data_file_path: str, attribute: str):
    '''
    get attributes passed alongside the file path
    if attribute is not passed None is returned
    '''
    ipa_file = __get_ipa_file()
    if ipa_file is None:
        return None

    for file in ipa_file['data_files']:
        if file['path'] == data_file_path:
            if attribute in file:
                return file[attribute]
            else:
                return None
    else:
        return None


def __read_args(script_name='script.py', version='1.0', message=''):
    if not hasattr(__read_args, "args"):
        args = '''
        {message}
Usage:
  {scriptPy}
  {scriptPy} <IPA_FILE>
  {scriptPy} [--data_files=<FILE>]... [--config_files=<FILE>]... --output_dir=<FILE>
  {scriptPy} (-h | --help)
  {scriptPy} --version

Options:
  -h --help     Show this screen.
  --version     Show version.
  -d FILE --data_files=<FILE>   The data files that are used.
  -c FILE --config_files=<FILE> The config files that are used.
  -o FILE --output_dir=<FILE>   The output directory. This is required if the script output directory.
'''
        __read_args.args = docopt(args.format(
            scriptPy=script_name, message=message), version=version)
    return __read_args.args


def __listafy(argument):
    '''make argument a list if it is not'''
    if not isinstance(argument, list):
        argument = [argument]
    return argument


def __is_strings(argument):
    return isinstance(argument, str)


def __is_list_of_strings(argument):
    if not isinstance(argument, list):
        return False
    return all(isinstance(item, str) for item in argument)


def __raise_if_none(argument, name: str):
    if argument is None:
        raise TypeError(
            "the {name} argument is not included in IPA_FILE".format(name=name))


def __is_using_ipa_file():
    file = __read_args()['<IPA_FILE>']
    return type(file) is str and file != ''


def __is_using_comandline_args():
    return __read_args()['--output_dir'] is not None


def __is_using_display_args():
    return not __is_using_ipa_file() and not __is_using_comandline_args()


def __get_args():
    ipa_file = __get_ipa_file()
    if ipa_file is not None:
        return ipa_file
    else:
        return __read_args()


def __get_files(file_arg, desktop_options):
    args = __get_args()
    files = None
    if __is_using_comandline_args():
        file_arg = '--' + file_arg
        if file_arg in args:
            files = __listafy(args[file_arg])
        return files
    elif __is_using_ipa_file():
        if file_arg in args:
            files = __listafy(args[file_arg])
        return files
    else:
        mtk = None
        mtk_filedialog = None
        try:
            mtk = import_module('tkinter')
            mtk_filedialog = import_module('tkinter.filedialog')
        except ModuleNotFoundError as err:
            raise err

        root = mtk.Tk()
        root.withdraw()
        root.focus_force()
        root.wm_attributes('-topmost', 1)
        return list(mtk_filedialog.askopenfilenames(**desktop_options))


def __get_directory(dir_arg, desktop_options):
    args = __get_args()
    directory = None
    if __is_using_comandline_args():
        dir_arg = '--' + dir_arg
        if dir_arg in args and __is_strings(args[dir_arg]):
            return args[dir_arg]
        else:
            raise TypeError(
                "the {dir_arg} argument is invalid".format(dir_arg=dir_arg))
    elif __is_using_ipa_file():
        if dir_arg in args:
            if __is_strings(args[dir_arg]):
                directory = args[dir_arg]
            else:
                raise TypeError(
                    "the {dir_arg} argument is invalid".format(dir_arg=dir_arg))
        return directory
    else:
        mtk = None
        mtk_filedialog = None
        try:
            mtk = import_module('tkinter')
            mtk_filedialog = import_module('tkinter.filedialog')
        except ModuleNotFoundError as err:
            raise err

        root = mtk.Tk()
        root.withdraw()
        root.focus_force()
        root.wm_attributes('-topmost', 1)
        return list(mtk_filedialog.askdirectory(**desktop_options))


def __to_array_of_paths(path_object):
    if (type(path_object) is list):
        paths = []
        for file in path_object:
            if type(file) is dict and 'path' in file and type(file['path']) is str:
                paths.append(file['path'])
            elif type(file) is str:
                paths.append(file)
        return paths
    elif (type(path_object) is str):
        return [path_object]
    else:
        return []


def __get_ipa_file():
    if hasattr(__get_ipa_file, 'ipa_file'):
        return __get_ipa_file.ipa_file
    if __is_using_ipa_file():
        __get_ipa_file.ipa_file = json.load(open(__read_args()['<IPA_FILE>']))
        return __get_ipa_file.ipa_file
    return None
